#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
###############################################################################
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
###############################################################################

###############################################################################
# Author: Stefan Senftleben
# Changed by: Bernd Mueller (bernd.mueller@de.lisega.com)
###############################################################################

# Programm name: cryptshare_check
# Plugin, das die Anzahl der Cryptshare-Transfers und der darin übertragenen
# Dateien misst.
# 23.09.2013
#
# Example output
#<<<cryptshare_check>>>
#Bereitstellungen 6 20 755294807 77 199 3115411122

from .agent_based_api.v1 import *

def discovery_cryptshare_check(section):
    yield Service()

def check_cryptshare_check(params, section):
    warnc, critc = params.get("warnc"), params.get("critc")
    warnf, critf = params.get("warnf"), params.get("critf")
    warnv, critv = params.get("warnv"), params.get("critv")
    for line in section:
        if line[0].startswith("Bereitstellungen"):
            daily_transfers  = int(section[0][1])
            daily_files  = int(section[0][2])
            daily_amount  = float(((float(section[0][3])/1024.0)/1024.0)/1024.0)
            transfers  = int(section[0][4])
            files  = int(section[0][5])
            amount  = float(((float(section[0][6])/1024.0)/1024.0)/1024.0)
            name = section[0][0]
            yield Metric(
                    "Transfer_Count",
                    daily_transfers,
                    levels=(warnc, critc),
                    )
            yield Metric(
                    "Transfer_Files",
                    daily_files,
                    levels=(warnf, critf),
                    )
            yield Metric(
                    "Transfer_Volume",
                    daily_amount,
                    levels=(warnv, critv),
                    )
            yield Result(state=(State.CRIT if daily_transfers >= critc or daily_files >= critf or daily_amount >= critv 
                else State.WARN if daily_transfers >= warnc or daily_files >= warnf or  daily_amount >= warnv 
                else State.OK),
                    summary = f"Transfers / Files / Volume: %s / %s / %.3f GB (today). %s / %s / %.3f GB (total)." % (daily_transfers,daily_files,daily_amount,transfers,files,amount))

register.check_plugin(
        name="cryptshare_check",
        service_name="Cryptshare Transfer",
        discovery_function=discovery_cryptshare_check,
        check_function=check_cryptshare_check,
        check_default_parameters={"warnc": 200, "critc": 500, "warnf": 300, "critf": 700, "warnv": 3, "critv": 4},
        check_ruleset_name='cryptshare_check',
)
